# Ko-reranker

The `ko-reranker` module is a reranker based on **korean**.
More details can be found [here](https://huggingface.co/Dongjin-kr/ko-reranker).


## **Module Parameters**
- **Not Applicable (N/A):** There are no direct module parameters specified for the `ko-reranker` module.

## **Example config.yaml**
```yaml
modules:
  - module_type: koreranker
```
